# kscale-mujoco-viewer

Mujoco viewer maintained by K-Scale Labs.

Originally referenced from [mujoco-python-viewer](https://github.com/gaolongsen/mujoco-python-viewer).

## Installation

```bash
pip install kscale-mujoco-viewer
```

## Usage

```python
import ksviewer
```

